/* Linear probability models */
/*March 16, 2007: Som*/

capture log close
capture drop _all

log using ../logfiles/Tables3&4new.out, text replace  /*TABLE 3 (clubbing results from Tables 3,4 in earlier version*/
 
use hhind_data_f_rev, clear

*list purify_type kind_change old_cost dexp expenditure if treatment==1 & raw_dirty==1 & purified_dirty==1 & flagpurify==1

/* TREATMENT EFFECT ON ENTIRE POPULATION: REFEREE's MAIN EFFECTS*/ 
/*Weighted to control for under-sampling of bottom and top of wealth distribution and oversampling of middle*/
/*Controlled for cluster effects at ward level*/
 
/* FULL SAMPLE */
/* Overall Effect of treatment on the Full Sample 
reg avertingbehavior treatment [pweight=invprobweight], cluster(enum_block_no)
reg change_purify treatment [pweight=invprobweight], cluster(enum_block_no)
reg expenditure treatment [pweight=invprobweight], cluster(enum_block_no)
reg discuss treatment [pweight=invprobweight], cluster(enum_block_no)
*/
/* TABLE 3: FULL SAMPLE (Coeffs of t_rw0 & t_rw1) */ 
/*Include raw_dirty in the regression to control for selection on the basis of source water quality */ 
reg avertingbehavior t_rw0 raw_dirty t_rw1 [pweight=invprobweight], cluster(enum_block_no)
reg change_purify t_rw0 raw_dirty t_rw1 [pweight=invprobweight], cluster(enum_block_no)
reg expenditure t_rw0 raw_dirty t_rw1 [pweight=invprobweight], cluster(enum_block_no)
reg dexp t_rw0 raw_dirty t_rw1 [pweight=invprobweight], cluster(enum_block_no)
reg discuss t_rw0 raw_dirty t_rw1 [pweight=invprobweight], cluster(enum_block_no)

/* TABLE 3: INITIAL NON-PURIFIERS*/
reg avertingbehavior t_rw0 raw_dirty t_rw1 [pweight=invprobweight] if flagpurify==0, cluster(enum_block_no)
reg change_purify t_rw0 raw_dirty t_rw1 [pweight=invprobweight] if flagpurify==0, cluster(enum_block_no)
reg expenditure t_rw0 raw_dirty t_rw1 [pweight=invprobweight] if flagpurify==0, cluster(enum_block_no)
reg dexp t_rw0 raw_dirty t_rw1 [pweight=invprobweight] if flagpurify==0, cluster(enum_block_no)
reg discuss t_rw0 raw_dirty t_rw1 [pweight=invprobweight] if flagpurify==0, cluster(enum_block_no)

/* TABLE 3: INITIAL PURIFIERS*/
reg avertingbehavior t_rw0 raw_dirty t_rw1 [pweight=invprobweight] if flagpurify==1, cluster(enum_block_no)
reg change_purify t_rw0 raw_dirty t_rw1 [pweight=invprobweight] if flagpurify==1, cluster(enum_block_no)
reg expenditure t_rw0 raw_dirty t_rw1 [pweight=invprobweight] if flagpurify==1, cluster(enum_block_no)
reg dexp t_rw0 raw_dirty t_rw1 [pweight=invprobweight] if flagpurify==1, cluster(enum_block_no)
reg discuss t_rw0 raw_dirty t_rw1 [pweight=invprobweight] if flagpurify==1, cluster(enum_block_no)

/* TEXT (ON NEW METHODS) */
tab new_purify_type if t_dw1==1 & flagpurify==0
tab new_purify_type if treatment==0 & flagpurify==0
tab change_purify if t_dw1==1 & flagpurify==0
tab change_purify if treatment==0 & flagpurify==0

/* TABLE 4 */
/*AWARENESS AND WEALTH REGRESSIONS FOR INITIAL NON-PURIFIERS*/ /*Estimating means of variables*/
summ wu if e(sample) & t_dw1==1 
scalar wu_bar = r(mean) 
summ au if e(sample) & t_dw1==1 
scalar au_bar = r(mean) 

reg avertingbehavior treatment wu tt_wu if flagpurify==0 & drink_water==1 [pweight=invprobweight], cluster(enum_block_no) 

reg expenditure treatment wu tt_wu if flagpurify==0 & drink_water==1 [pweight=invprobweight], cluster(enum_block_no) 
reg expenditure treatment wu tt_wu au tt_au if flagpurify==0 & drink_water==1 [pweight=invprobweight], cluster(enum_block_no) 
reg expenditure treatment wu tt_wu feu tt_feu if flagpurify==0 & drink_water==1 [pweight=invprobweight], cluster(enum_block_no) 
reg expenditure treatment wu tt_wu maxfedu treatment_maxfedu if flagpurify==0 & drink_water==1 [pweight=invprobweight], cluster(enum_block_no) 

reg discuss treatment wu tt_wu if flagpurify==0 & drink_water==1 [pweight=invprobweight], cluster(enum_block_no) 

reg avertingbehavior treatment au tt_au if flagpurify==0 & drink_water==1 [pweight=invprobweight], cluster(enum_block_no) 
reg expenditure treatment au tt_au if flagpurify==0 & drink_water==1 [pweight=invprobweight], cluster(enum_block_no) 
reg discuss treatment au tt_au if flagpurify==0 & drink_water==1 [pweight=invprobweight], cluster(enum_block_no) 

reg avertingbehavior treatment feu tt_feu if flagpurify==0 & drink_water==1 [pweight=invprobweight], cluster(enum_block_no) 
reg expenditure treatment feu tt_feu if flagpurify==0 & drink_water==1 [pweight=invprobweight], cluster(enum_block_no) 
reg discuss treatment feu tt_feu if flagpurify==0 & drink_water==1 [pweight=invprobweight], cluster(enum_block_no) 


/* TEXT: Impact of positive result on mean expenditure in the sample */
su old_cost[aw=invprobweight]
scalar old_cost_mean = r(mean) 
dis "Mean in PPP dollars = " old_cost_mean/9

su old_cost if flagpurify==1 [aw=invprobweight]  
scalar ip_cost_mean = r(mean) 
dis "Mean among initial purifiers in PPP dollars = " ip_cost_mean/9

gen dirty_nip_dummy = drink_water==1 & flagpurify==0 
summ dirty_nip_dummy [aw=invprobweight]
scalar frac_dirty_nip = r(mean)
display (frac_dirty_nip*65.18026)/old_cost_mean

/*Aggregate Regressions*/ /*TEXT: Households who have adopted a new method in third visit and were not purifying earlier*/ 
gen upgrade=(kind_change==1) 
reg upgrade t_rw1 t_rw0 if flagpurify==0 [pweight=invprobweight], cluster(enum_block_no) 
lincom t_rw1+t_rw0 

reg expenditure t_rw1 t_rw0 if flagpurify==0 [pweight=invprobweight], cluster(enum_block_no) 
lincom t_rw1+t_rw0 

/* TEXT: Double interaction of wealth and awareness with positive result */
reg avertingbehavior t_dw0 t_dw1 t_dw1_au drink_water if flagpurify==0 & wu==1 [pweight=invprobweight],cluster(enum_block_no) 

/*Appendix Table 1 (new): Appendix Table 2 from current version*/

/*TEXT: Effect on households that were using non-electric filter previously but now have*/  
/*switched to a more effective method of purification: Effect of handout. Mention in text*/  

gen upgrade2=(kind_change==1 & new_method~=5) 
/*reg upgrade2 t_dw1 t_dw0 drink_water if purify_type==3 [pweight=invprobweight], cluster(enum_block_no)*/ 
/*lincom t_dw1+t_dw0 reg expenditure t_dw1 t_dw0 drink_water if purify_type==3 [pweight=invprobweight], cluster(enum_block_no)*/ 
/*lincom t_dw1+t_dw0*/ 

/*TEXT: Households who were purifying earlier and downgraded because of a negative test result*/ 
/*on unpurified water*/ 
gen downgrade=(kind_change==2) 
reg downgrade t_rw1 t_rw0 raw_water if flagpurify==1 [pweight=invprobweight],cluster(enum_block_no) 
lincom t_rw1+t_rw0 

reg expenditure t_rw1 t_rw0 raw_water if flagpurify==1 [pweight=invprobweight],cluster(enum_block_no) 
lincom t_rw1+t_rw0 

/*TEXT*/ /*Wealth and education effects: Discuss in the text*/ 
reg avertingbehavior t_dw1 t_dw0 t_dw1_wu t_dw1_maxfedu drink_water if flagpurify==0 [pweight=invprobweight],cluster(enum_block_no) 
summ maxfedu if e(sample) & t_dw1==1
scalar maxfedu_bar = r(mean) 
lincom _b[t_dw1] + _b[t_dw1_wu]*wu_bar + _b[t_dw1_maxfedu]*maxfedu_bar 

reg discuss t_dw1 t_dw0 t_dw1_wu t_dw1_maxfedu drink_water if flagpurify==0 [pweight=invprobweight],cluster(enum_block_no) 
lincom _b[t_dw1] + _b[t_dw1_wu]*wu_bar + _b[t_dw1_maxfedu]*maxfedu_bar 
 
reg expenditure t_dw1 t_dw0 t_dw1_wu t_dw1_maxfedu drink_water if flagpurify==0 [pweight=invprobweight],cluster(enum_block_no) 
lincom _b[t_dw1] + _b[t_dw1_wu]*wu_bar + _b[t_dw1_maxfedu]*maxfedu_bar
 
dprobit avertingbehavior t_dw1 t_dw0 t_dw1_wu t_dw1_maxfedu drink_water if flagpurify==0 [pweight=invprobweight],cluster(enum_block_no) 
summ maxfedu if e(sample) & t_dw1==1
scalar maxfedu_bar = r(mean) 
lincom _b[t_dw1] + _b[t_dw1_wu]*wu_bar + _b[t_dw1_maxfedu]*maxfedu_bar
 
dprobit discuss t_dw1 t_dw0 t_dw1_wu t_dw1_maxfedu drink_water if flagpurify==0 [pweight=invprobweight],cluster(enum_block_no) 
lincom _b[t_dw1] + _b[t_dw1_wu]*wu_bar + _b[t_dw1_maxfedu]*maxfedu_bar  
reg expenditure t_dw1 t_dw0 t_dw1_wu t_dw1_maxfedu drink_water if flagpurify==0 [pweight=invprobweight],cluster(enum_block_no) 
lincom _b[t_dw1] + _b[t_dw1_wu]*wu_bar + _b[t_dw1_maxfedu]*maxfedu_bar 

/*APPENDIX TABLE: PROBIT (DESCRIPTIVE REGRESSION)*/
gen agesq=age_head^2
egen median_w=median(wealth)

gen occupation=occupation_head
replace occupation=4 if occupation_head==0
tab occupation, gen(occupation_head)

set more off
#delimit;
dprobit flagpurify wealth awareness maxfedu maxmedu child0t3 no_members sex_head age_head agesq occupation_head1 occupation_head2 
occupation_head3 occupation_head5 [pweight=invprobweight], cluster(enum_block_no);

dprobit flagpurify wealth awareness maxfedu maxmedu child0t3 no_members sex_head age_head agesq occupation_head1 occupation_head2 
occupation_head3 occupation_head5 [pweight=invprobweight] if wealth>=median_w, cluster(enum_block_no);

dprobit flagpurify wealth awareness maxfedu maxmedu child0t3 no_members sex_head age_head agesq occupation_head1 occupation_head2 
occupation_head3 occupation_head5 [pweight=invprobweight] if wealth<median_w, cluster(enum_block_no);

reg old_cost wealth awareness maxfedu maxmedu child0t3 no_members sex_head age_head agesq occupation_head1 occupation_head2 
occupation_head3 occupation_head5 [pweight=invprobweight], cluster(enum_block_no);

log close;

